pub struct KeyEncryptionKey {
pub kek_type: KekType,
pub identity_properties: Option<IdentityProperties>,
pub kek_url: Option<String>,
pub kek_vault_resource_id: Option<String>,
}Expand description
Encryption key containing details about key to encrypt different keys.
Fields
kek_type: KekTypeType of encryption key used for key encryption.
identity_properties: Option<IdentityProperties>Managed identity properties.
kek_url: Option<String>Key encryption key. It is required in case of Customer managed KekType.
kek_vault_resource_id: Option<String>Kek vault resource id. It is required in case of Customer managed KekType.
Implementations